# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Discounts.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Discounts.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n!io.opencannabis.schema.accountingB\023CommercialDiscountsH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%opencannabis/commerce/Discounts.proto\x12\x15opencannabis.commerce\x1a#opencannabis/temporal/Instant.proto\"\xac\x01\n\x0c\x44iscountSpec\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.opencannabis.commerce.DiscountType\x12\x33\n\x05\x62\x61sis\x18\x02 \x01(\x0e\x32$.opencannabis.commerce.DiscountBasis\x12\x14\n\npercentage\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstatic_value\x18\x04 \x01(\x01H\x00\x42\x06\n\x04rate\"\xe4\x01\n\x08\x44iscount\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32#.opencannabis.commerce.DiscountSpec\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05label\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x33\n\x0bmodified_at\x18\x07 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x32\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant*9\n\x0c\x44iscountType\x12\n\n\x06\x43USTOM\x10\x00\x12\r\n\tSTATUTORY\x10\x01\x12\x0e\n\nCOMMERCIAL\x10\x02*>\n\rDiscountBasis\x12\x08\n\x04ITEM\x10\x00\x12\x12\n\x0eORDER_SUBTOTAL\x10\x01\x12\x0f\n\x0bORDER_TOTAL\x10\x02\x42\x42\n!io.opencannabis.schema.accountingB\x13\x43ommercialDiscountsH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])

_DISCOUNTTYPE = _descriptor.EnumDescriptor(
  name='DiscountType',
  full_name='opencannabis.commerce.DiscountType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CUSTOM', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATUTORY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMERCIAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=507,
  serialized_end=564,
)
_sym_db.RegisterEnumDescriptor(_DISCOUNTTYPE)

DiscountType = enum_type_wrapper.EnumTypeWrapper(_DISCOUNTTYPE)
_DISCOUNTBASIS = _descriptor.EnumDescriptor(
  name='DiscountBasis',
  full_name='opencannabis.commerce.DiscountBasis',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ITEM', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_SUBTOTAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER_TOTAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=566,
  serialized_end=628,
)
_sym_db.RegisterEnumDescriptor(_DISCOUNTBASIS)

DiscountBasis = enum_type_wrapper.EnumTypeWrapper(_DISCOUNTBASIS)
CUSTOM = 0
STATUTORY = 1
COMMERCIAL = 2
ITEM = 0
ORDER_SUBTOTAL = 1
ORDER_TOTAL = 2



_DISCOUNTSPEC = _descriptor.Descriptor(
  name='DiscountSpec',
  full_name='opencannabis.commerce.DiscountSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.commerce.DiscountSpec.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='basis', full_name='opencannabis.commerce.DiscountSpec.basis', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='opencannabis.commerce.DiscountSpec.percentage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_value', full_name='opencannabis.commerce.DiscountSpec.static_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='rate', full_name='opencannabis.commerce.DiscountSpec.rate',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=102,
  serialized_end=274,
)


_DISCOUNT = _descriptor.Descriptor(
  name='Discount',
  full_name='opencannabis.commerce.Discount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.commerce.Discount.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='opencannabis.commerce.Discount.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.commerce.Discount.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='opencannabis.commerce.Discount.label', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='opencannabis.commerce.Discount.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified_at', full_name='opencannabis.commerce.Discount.modified_at', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='opencannabis.commerce.Discount.created_at', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=505,
)

_DISCOUNTSPEC.fields_by_name['type'].enum_type = _DISCOUNTTYPE
_DISCOUNTSPEC.fields_by_name['basis'].enum_type = _DISCOUNTBASIS
_DISCOUNTSPEC.oneofs_by_name['rate'].fields.append(
  _DISCOUNTSPEC.fields_by_name['percentage'])
_DISCOUNTSPEC.fields_by_name['percentage'].containing_oneof = _DISCOUNTSPEC.oneofs_by_name['rate']
_DISCOUNTSPEC.oneofs_by_name['rate'].fields.append(
  _DISCOUNTSPEC.fields_by_name['static_value'])
_DISCOUNTSPEC.fields_by_name['static_value'].containing_oneof = _DISCOUNTSPEC.oneofs_by_name['rate']
_DISCOUNT.fields_by_name['spec'].message_type = _DISCOUNTSPEC
_DISCOUNT.fields_by_name['modified_at'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_DISCOUNT.fields_by_name['created_at'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
DESCRIPTOR.message_types_by_name['DiscountSpec'] = _DISCOUNTSPEC
DESCRIPTOR.message_types_by_name['Discount'] = _DISCOUNT
DESCRIPTOR.enum_types_by_name['DiscountType'] = _DISCOUNTTYPE
DESCRIPTOR.enum_types_by_name['DiscountBasis'] = _DISCOUNTBASIS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiscountSpec = _reflection.GeneratedProtocolMessageType('DiscountSpec', (_message.Message,), {
  'DESCRIPTOR' : _DISCOUNTSPEC,
  '__module__' : 'opencannabis.commerce.Discounts_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.DiscountSpec)
  })
_sym_db.RegisterMessage(DiscountSpec)

Discount = _reflection.GeneratedProtocolMessageType('Discount', (_message.Message,), {
  'DESCRIPTOR' : _DISCOUNT,
  '__module__' : 'opencannabis.commerce.Discounts_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.Discount)
  })
_sym_db.RegisterMessage(Discount)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.contact`
  ---------------------------
  Contact information models, including email addresses/phone numbers, etc.

"""

# `opencannabis.contact`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Date.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Date.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\014TemporalDateH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/temporal/Date.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"`\n\x04\x44\x61te\x12P\n\x07iso8601\x18\x01 \x01(\tB=\xc2\xb5\x03\x39\x12\x37ISO8601-formatted calendar date value, like YYYY-MM-DD.H\x00\x42\x06\n\x04specB9\n\x1fio.opencannabis.schema.temporalB\x0cTemporalDateH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='opencannabis.temporal.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iso8601', full_name='opencannabis.temporal.Date.iso8601', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039\0227ISO8601-formatted calendar date value, like YYYY-MM-DD.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.temporal.Date.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86,
  serialized_end=182,
)

_DATE.oneofs_by_name['spec'].fields.append(
  _DATE.fields_by_name['iso8601'])
_DATE.fields_by_name['iso8601'].containing_oneof = _DATE.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Date'] = _DATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
  'DESCRIPTOR' : _DATE,
  '__module__' : 'opencannabis.temporal.Date_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Date)
  })
_sym_db.RegisterMessage(Date)


DESCRIPTOR._options = None
_DATE.fields_by_name['iso8601']._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.structs.labtesting`
  -------------------------------------
  Structures and definitions that define cannabis lab testing records.

"""

# `opencannabis.structs.labtesting`



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.products.menu`
  -------------------------------------
  Objects that gather products into menu structures.

"""

# `opencannabis.products.menu`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/base/Compression.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/base/Compression.proto',
  package='opencannabis.base',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.baseB\017BaseCompressionH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/base/Compression.proto\x12\x11opencannabis.base\"\x8f\x01\n\x0b\x43ompression\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.opencannabis.base.Compression.Type\"<\n\x04Type\x12\x12\n\x0eNO_COMPRESSION\x10\x00\x12\x08\n\x04GZIP\x10\x01\x12\n\n\x06\x42ROTLI\x10\x02\x12\n\n\x06SNAPPY\x10\x03\x42\x38\n\x1bio.opencannabis.schema.baseB\x0f\x42\x61seCompressionH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)



_COMPRESSION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.base.Compression.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_COMPRESSION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GZIP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROTLI', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPPY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=142,
  serialized_end=202,
)
_sym_db.RegisterEnumDescriptor(_COMPRESSION_TYPE)


_COMPRESSION = _descriptor.Descriptor(
  name='Compression',
  full_name='opencannabis.base.Compression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='opencannabis.base.Compression.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.base.Compression.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPRESSION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=202,
)

_COMPRESSION.fields_by_name['type'].enum_type = _COMPRESSION_TYPE
_COMPRESSION_TYPE.containing_type = _COMPRESSION
DESCRIPTOR.message_types_by_name['Compression'] = _COMPRESSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Compression = _reflection.GeneratedProtocolMessageType('Compression', (_message.Message,), {
  'DESCRIPTOR' : _COMPRESSION,
  '__module__' : 'opencannabis.base.Compression_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.base.Compression)
  })
_sym_db.RegisterMessage(Compression)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/labtesting/TestValue.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.media import MediaItem_pb2 as opencannabis_dot_media_dot_MediaItem__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/labtesting/TestValue.proto',
  package='opencannabis.structs.labtesting',
  syntax='proto3',
  serialized_options=b'\n-io.opencannabis.schema.product.struct.testingB\017BaseTestingSpecH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n/opencannabis/structs/labtesting/TestValue.proto\x12\x1fopencannabis.structs.labtesting\x1a\"opencannabis/media/MediaItem.proto\"\x9b\x02\n\tTestValue\x12<\n\x04type\x18\x01 \x01(\x0e\x32..opencannabis.structs.labtesting.TestValueType\x12\x43\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x34.opencannabis.structs.labtesting.TestValue.TestError\x12\x15\n\x0bmeasurement\x18\n \x01(\x01H\x00\x12\x11\n\x07present\x18\x14 \x01(\x08H\x00\x1aX\n\tTestError\x12<\n\x04type\x18\x01 \x01(\x0e\x32..opencannabis.structs.labtesting.TestErrorType\x12\r\n\x05value\x18\x02 \x01(\x01\x42\x07\n\x05value\"|\n\tTestMedia\x12<\n\x04type\x18\x01 \x01(\x0e\x32..opencannabis.structs.labtesting.TestMediaType\x12\x31\n\nmedia_item\x18\x02 \x01(\x0b\x32\x1d.opencannabis.media.MediaItem*V\n\rTestValueType\x12\x0e\n\nMILLIGRAMS\x10\x00\x12\x0e\n\nPERCENTAGE\x10\x01\x12\x0c\n\x08PRESENCE\x10\x02\x12\x17\n\x13MILLIGRAMS_PER_GRAM\x10\x03*8\n\rTestErrorType\x12\x0b\n\x07PERCENT\x10\x00\x12\x0c\n\x08\x41\x42SOLUTE\x10\x01\x12\x0c\n\x08RELATIVE\x10\x02*@\n\rTestMediaType\x12\x0f\n\x0b\x43\x45RTIFICATE\x10\x00\x12\x0b\n\x07RESULTS\x10\x01\x12\x11\n\rPRODUCT_IMAGE\x10\x02\x42J\n-io.opencannabis.schema.product.struct.testingB\x0f\x42\x61seTestingSpecH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_media_dot_MediaItem__pb2.DESCRIPTOR,])

_TESTVALUETYPE = _descriptor.EnumDescriptor(
  name='TestValueType',
  full_name='opencannabis.structs.labtesting.TestValueType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MILLIGRAMS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERCENTAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRESENCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILLIGRAMS_PER_GRAM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=532,
  serialized_end=618,
)
_sym_db.RegisterEnumDescriptor(_TESTVALUETYPE)

TestValueType = enum_type_wrapper.EnumTypeWrapper(_TESTVALUETYPE)
_TESTERRORTYPE = _descriptor.EnumDescriptor(
  name='TestErrorType',
  full_name='opencannabis.structs.labtesting.TestErrorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERCENT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ABSOLUTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELATIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=620,
  serialized_end=676,
)
_sym_db.RegisterEnumDescriptor(_TESTERRORTYPE)

TestErrorType = enum_type_wrapper.EnumTypeWrapper(_TESTERRORTYPE)
_TESTMEDIATYPE = _descriptor.EnumDescriptor(
  name='TestMediaType',
  full_name='opencannabis.structs.labtesting.TestMediaType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CERTIFICATE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESULTS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT_IMAGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=678,
  serialized_end=742,
)
_sym_db.RegisterEnumDescriptor(_TESTMEDIATYPE)

TestMediaType = enum_type_wrapper.EnumTypeWrapper(_TESTMEDIATYPE)
MILLIGRAMS = 0
PERCENTAGE = 1
PRESENCE = 2
MILLIGRAMS_PER_GRAM = 3
PERCENT = 0
ABSOLUTE = 1
RELATIVE = 2
CERTIFICATE = 0
RESULTS = 1
PRODUCT_IMAGE = 2



_TESTVALUE_TESTERROR = _descriptor.Descriptor(
  name='TestError',
  full_name='opencannabis.structs.labtesting.TestValue.TestError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.structs.labtesting.TestValue.TestError.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.structs.labtesting.TestValue.TestError.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=307,
  serialized_end=395,
)

_TESTVALUE = _descriptor.Descriptor(
  name='TestValue',
  full_name='opencannabis.structs.labtesting.TestValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.structs.labtesting.TestValue.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='opencannabis.structs.labtesting.TestValue.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement', full_name='opencannabis.structs.labtesting.TestValue.measurement', index=2,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='present', full_name='opencannabis.structs.labtesting.TestValue.present', index=3,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TESTVALUE_TESTERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='opencannabis.structs.labtesting.TestValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=121,
  serialized_end=404,
)


_TESTMEDIA = _descriptor.Descriptor(
  name='TestMedia',
  full_name='opencannabis.structs.labtesting.TestMedia',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.structs.labtesting.TestMedia.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media_item', full_name='opencannabis.structs.labtesting.TestMedia.media_item', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=530,
)

_TESTVALUE_TESTERROR.fields_by_name['type'].enum_type = _TESTERRORTYPE
_TESTVALUE_TESTERROR.containing_type = _TESTVALUE
_TESTVALUE.fields_by_name['type'].enum_type = _TESTVALUETYPE
_TESTVALUE.fields_by_name['error'].message_type = _TESTVALUE_TESTERROR
_TESTVALUE.oneofs_by_name['value'].fields.append(
  _TESTVALUE.fields_by_name['measurement'])
_TESTVALUE.fields_by_name['measurement'].containing_oneof = _TESTVALUE.oneofs_by_name['value']
_TESTVALUE.oneofs_by_name['value'].fields.append(
  _TESTVALUE.fields_by_name['present'])
_TESTVALUE.fields_by_name['present'].containing_oneof = _TESTVALUE.oneofs_by_name['value']
_TESTMEDIA.fields_by_name['type'].enum_type = _TESTMEDIATYPE
_TESTMEDIA.fields_by_name['media_item'].message_type = opencannabis_dot_media_dot_MediaItem__pb2._MEDIAITEM
DESCRIPTOR.message_types_by_name['TestValue'] = _TESTVALUE
DESCRIPTOR.message_types_by_name['TestMedia'] = _TESTMEDIA
DESCRIPTOR.enum_types_by_name['TestValueType'] = _TESTVALUETYPE
DESCRIPTOR.enum_types_by_name['TestErrorType'] = _TESTERRORTYPE
DESCRIPTOR.enum_types_by_name['TestMediaType'] = _TESTMEDIATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TestValue = _reflection.GeneratedProtocolMessageType('TestValue', (_message.Message,), {

  'TestError' : _reflection.GeneratedProtocolMessageType('TestError', (_message.Message,), {
    'DESCRIPTOR' : _TESTVALUE_TESTERROR,
    '__module__' : 'opencannabis.structs.labtesting.TestValue_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.structs.labtesting.TestValue.TestError)
    })
  ,
  'DESCRIPTOR' : _TESTVALUE,
  '__module__' : 'opencannabis.structs.labtesting.TestValue_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.labtesting.TestValue)
  })
_sym_db.RegisterMessage(TestValue)
_sym_db.RegisterMessage(TestValue.TestError)

TestMedia = _reflection.GeneratedProtocolMessageType('TestMedia', (_message.Message,), {
  'DESCRIPTOR' : _TESTMEDIA,
  '__module__' : 'opencannabis.structs.labtesting.TestValue_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.labtesting.TestMedia)
  })
_sym_db.RegisterMessage(TestMedia)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/menu/Section.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2
from opencannabis.media import MediaItem_pb2 as opencannabis_dot_media_dot_MediaItem__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/menu/Section.proto',
  package='opencannabis.products.menu.section',
  syntax='proto3',
  serialized_options=b'\n#io.opencannabis.schema.menu.sectionH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(opencannabis/products/menu/Section.proto\x12\"opencannabis.products.menu.section\x1a\x1fopencannabis/content/Name.proto\x1a\"opencannabis/media/MediaItem.proto\"`\n\rCustomSection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x43\n\x06\x66ilter\x18\x02 \x01(\x0e\x32\x33.opencannabis.products.menu.section.FilteredSection\"N\n\x0cSectionMedia\x12>\n\x17tablet_homescreen_media\x18\x02 \x01(\x0b\x32\x1d.opencannabis.media.MediaItem\"|\n\x0fSectionSettings\x12(\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.Name\x12?\n\x05media\x18\x02 \x01(\x0b\x32\x30.opencannabis.products.menu.section.SectionMedia\"\xb9\x02\n\x0bSectionSpec\x12>\n\x07section\x18\x01 \x01(\x0e\x32+.opencannabis.products.menu.section.SectionH\x00\x12K\n\x0e\x63ustom_section\x18\x02 \x01(\x0b\x32\x31.opencannabis.products.menu.section.CustomSectionH\x00\x12\x0e\n\x04name\x18\x03 \x01(\tH\x00\x12\x45\n\x08settings\x18\x04 \x01(\x0b\x32\x33.opencannabis.products.menu.section.SectionSettings\x12>\n\x05\x66lags\x18\x05 \x03(\x0e\x32/.opencannabis.products.menu.section.SectionFlagB\x06\n\x04spec*\'\n\x0bSectionFlag\x12\n\n\x06HIDDEN\x10\x00\x12\x0c\n\x08\x46\x45\x41TURED\x10\x01*\x8d\x01\n\x07Section\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07\x46LOWERS\x10\x01\x12\x0c\n\x08\x45XTRACTS\x10\x02\x12\x0b\n\x07\x45\x44IBLES\x10\x03\x12\x0e\n\nCARTRIDGES\x10\x04\x12\x0e\n\nAPOTHECARY\x10\x05\x12\x0c\n\x08PREROLLS\x10\x06\x12\n\n\x06PLANTS\x10\x07\x12\x0f\n\x0bMERCHANDISE\x10\x08*>\n\x0f\x46ilteredSection\x12\x0b\n\x07ON_SALE\x10\x00\x12\t\n\x05HOUSE\x10\x01\x12\x07\n\x03\x43\x42\x44\x10\x02\x12\n\n\x06SEARCH\x10\x03\x42/\n#io.opencannabis.schema.menu.sectionH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaItem__pb2.DESCRIPTOR,])

_SECTIONFLAG = _descriptor.EnumDescriptor(
  name='SectionFlag',
  full_name='opencannabis.products.menu.section.SectionFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HIDDEN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=769,
  serialized_end=808,
)
_sym_db.RegisterEnumDescriptor(_SECTIONFLAG)

SectionFlag = enum_type_wrapper.EnumTypeWrapper(_SECTIONFLAG)
_SECTION = _descriptor.EnumDescriptor(
  name='Section',
  full_name='opencannabis.products.menu.section.Section',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLOWERS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTRACTS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EDIBLES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CARTRIDGES', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APOTHECARY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREROLLS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANTS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MERCHANDISE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=811,
  serialized_end=952,
)
_sym_db.RegisterEnumDescriptor(_SECTION)

Section = enum_type_wrapper.EnumTypeWrapper(_SECTION)
_FILTEREDSECTION = _descriptor.EnumDescriptor(
  name='FilteredSection',
  full_name='opencannabis.products.menu.section.FilteredSection',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ON_SALE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEARCH', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=954,
  serialized_end=1016,
)
_sym_db.RegisterEnumDescriptor(_FILTEREDSECTION)

FilteredSection = enum_type_wrapper.EnumTypeWrapper(_FILTEREDSECTION)
HIDDEN = 0
FEATURED = 1
UNSPECIFIED = 0
FLOWERS = 1
EXTRACTS = 2
EDIBLES = 3
CARTRIDGES = 4
APOTHECARY = 5
PREROLLS = 6
PLANTS = 7
MERCHANDISE = 8
ON_SALE = 0
HOUSE = 1
CBD = 2
SEARCH = 3



_CUSTOMSECTION = _descriptor.Descriptor(
  name='CustomSection',
  full_name='opencannabis.products.menu.section.CustomSection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.products.menu.section.CustomSection.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='opencannabis.products.menu.section.CustomSection.filter', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=245,
)


_SECTIONMEDIA = _descriptor.Descriptor(
  name='SectionMedia',
  full_name='opencannabis.products.menu.section.SectionMedia',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tablet_homescreen_media', full_name='opencannabis.products.menu.section.SectionMedia.tablet_homescreen_media', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=325,
)


_SECTIONSETTINGS = _descriptor.Descriptor(
  name='SectionSettings',
  full_name='opencannabis.products.menu.section.SectionSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.products.menu.section.SectionSettings.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.products.menu.section.SectionSettings.media', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=451,
)


_SECTIONSPEC = _descriptor.Descriptor(
  name='SectionSpec',
  full_name='opencannabis.products.menu.section.SectionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='section', full_name='opencannabis.products.menu.section.SectionSpec.section', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_section', full_name='opencannabis.products.menu.section.SectionSpec.custom_section', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.products.menu.section.SectionSpec.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='opencannabis.products.menu.section.SectionSpec.settings', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.menu.section.SectionSpec.flags', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.products.menu.section.SectionSpec.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=454,
  serialized_end=767,
)

_CUSTOMSECTION.fields_by_name['filter'].enum_type = _FILTEREDSECTION
_SECTIONMEDIA.fields_by_name['tablet_homescreen_media'].message_type = opencannabis_dot_media_dot_MediaItem__pb2._MEDIAITEM
_SECTIONSETTINGS.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_SECTIONSETTINGS.fields_by_name['media'].message_type = _SECTIONMEDIA
_SECTIONSPEC.fields_by_name['section'].enum_type = _SECTION
_SECTIONSPEC.fields_by_name['custom_section'].message_type = _CUSTOMSECTION
_SECTIONSPEC.fields_by_name['settings'].message_type = _SECTIONSETTINGS
_SECTIONSPEC.fields_by_name['flags'].enum_type = _SECTIONFLAG
_SECTIONSPEC.oneofs_by_name['spec'].fields.append(
  _SECTIONSPEC.fields_by_name['section'])
_SECTIONSPEC.fields_by_name['section'].containing_oneof = _SECTIONSPEC.oneofs_by_name['spec']
_SECTIONSPEC.oneofs_by_name['spec'].fields.append(
  _SECTIONSPEC.fields_by_name['custom_section'])
_SECTIONSPEC.fields_by_name['custom_section'].containing_oneof = _SECTIONSPEC.oneofs_by_name['spec']
_SECTIONSPEC.oneofs_by_name['spec'].fields.append(
  _SECTIONSPEC.fields_by_name['name'])
_SECTIONSPEC.fields_by_name['name'].containing_oneof = _SECTIONSPEC.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['CustomSection'] = _CUSTOMSECTION
DESCRIPTOR.message_types_by_name['SectionMedia'] = _SECTIONMEDIA
DESCRIPTOR.message_types_by_name['SectionSettings'] = _SECTIONSETTINGS
DESCRIPTOR.message_types_by_name['SectionSpec'] = _SECTIONSPEC
DESCRIPTOR.enum_types_by_name['SectionFlag'] = _SECTIONFLAG
DESCRIPTOR.enum_types_by_name['Section'] = _SECTION
DESCRIPTOR.enum_types_by_name['FilteredSection'] = _FILTEREDSECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomSection = _reflection.GeneratedProtocolMessageType('CustomSection', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMSECTION,
  '__module__' : 'opencannabis.products.menu.Section_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.section.CustomSection)
  })
_sym_db.RegisterMessage(CustomSection)

SectionMedia = _reflection.GeneratedProtocolMessageType('SectionMedia', (_message.Message,), {
  'DESCRIPTOR' : _SECTIONMEDIA,
  '__module__' : 'opencannabis.products.menu.Section_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.section.SectionMedia)
  })
_sym_db.RegisterMessage(SectionMedia)

SectionSettings = _reflection.GeneratedProtocolMessageType('SectionSettings', (_message.Message,), {
  'DESCRIPTOR' : _SECTIONSETTINGS,
  '__module__' : 'opencannabis.products.menu.Section_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.section.SectionSettings)
  })
_sym_db.RegisterMessage(SectionSettings)

SectionSpec = _reflection.GeneratedProtocolMessageType('SectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _SECTIONSPEC,
  '__module__' : 'opencannabis.products.menu.Section_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.section.SectionSpec)
  })
_sym_db.RegisterMessage(SectionSpec)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/ProductContent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2
from opencannabis.content import Content_pb2 as opencannabis_dot_content_dot_Content__pb2
from opencannabis.content import Brand_pb2 as opencannabis_dot_content_dot_Brand__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.media import MediaKey_pb2 as opencannabis_dot_media_dot_MediaKey__pb2
from opencannabis.structs import ProductFlags_pb2 as opencannabis_dot_structs_dot_ProductFlags__pb2
from opencannabis.structs.labtesting import TestResults_pb2 as opencannabis_dot_structs_dot_labtesting_dot_TestResults__pb2
from opencannabis.structs.pricing import PricingDescriptor_pb2 as opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/ProductContent.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\017AttachedContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)opencannabis/content/ProductContent.proto\x12\x14opencannabis.content\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/content/Name.proto\x1a\"opencannabis/content/Content.proto\x1a opencannabis/content/Brand.proto\x1a#opencannabis/temporal/Instant.proto\x1a!opencannabis/media/MediaKey.proto\x1a\'opencannabis/structs/ProductFlags.proto\x1a\x31opencannabis/structs/labtesting/TestResults.proto\x1a\x34opencannabis/structs/pricing/PricingDescriptor.proto\"\xa9\x01\n\x11ProductTimestamps\x12/\n\x07\x63reated\x18\x01 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x30\n\x08modified\x18\x02 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x31\n\tpublished\x18\x03 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\"\x98\x04\n\x0eProductContent\x12(\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.Name\x12*\n\x05\x62rand\x18\x02 \x01(\x0b\x32\x1b.opencannabis.content.Brand\x12.\n\x07summary\x18\x03 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12,\n\x05usage\x18\x04 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12-\n\x06\x64osage\x18\x05 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12@\n\x05media\x18\x06 \x03(\x0b\x32\".opencannabis.media.MediaReferenceB\r\xd2\xb5\x03\t\x08\x01\x1a\x05media\x12=\n\x07pricing\x18\x07 \x01(\x0b\x32,.opencannabis.structs.pricing.ProductPricing\x12;\n\x05tests\x18\x08 \x01(\x0b\x32,.opencannabis.structs.labtesting.TestResults\x12\x30\n\x05\x66lags\x18\t \x03(\x0e\x32!.opencannabis.structs.ProductFlag\x12\x33\n\x02ts\x18\n \x01(\x0b\x32\'.opencannabis.content.ProductTimestampsB;\n\x1eio.opencannabis.schema.contentB\x0f\x41ttachedContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Content__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Brand__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaKey__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_ProductFlags__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_labtesting_dot_TestResults__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2.DESCRIPTOR,])




_PRODUCTTIMESTAMPS = _descriptor.Descriptor(
  name='ProductTimestamps',
  full_name='opencannabis.content.ProductTimestamps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.content.ProductTimestamps.created', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='opencannabis.content.ProductTimestamps.modified', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published', full_name='opencannabis.content.ProductTimestamps.published', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=585,
)


_PRODUCTCONTENT = _descriptor.Descriptor(
  name='ProductContent',
  full_name='opencannabis.content.ProductContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.content.ProductContent.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brand', full_name='opencannabis.content.ProductContent.brand', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='opencannabis.content.ProductContent.summary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='opencannabis.content.ProductContent.usage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dosage', full_name='opencannabis.content.ProductContent.dosage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.content.ProductContent.media', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\322\265\003\t\010\001\032\005media', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pricing', full_name='opencannabis.content.ProductContent.pricing', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tests', full_name='opencannabis.content.ProductContent.tests', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.content.ProductContent.flags', index=8,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='opencannabis.content.ProductContent.ts', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=1124,
)

_PRODUCTTIMESTAMPS.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_PRODUCTTIMESTAMPS.fields_by_name['modified'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_PRODUCTTIMESTAMPS.fields_by_name['published'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_PRODUCTCONTENT.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_PRODUCTCONTENT.fields_by_name['brand'].message_type = opencannabis_dot_content_dot_Brand__pb2._BRAND
_PRODUCTCONTENT.fields_by_name['summary'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_PRODUCTCONTENT.fields_by_name['usage'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_PRODUCTCONTENT.fields_by_name['dosage'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_PRODUCTCONTENT.fields_by_name['media'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_PRODUCTCONTENT.fields_by_name['pricing'].message_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRODUCTPRICING
_PRODUCTCONTENT.fields_by_name['tests'].message_type = opencannabis_dot_structs_dot_labtesting_dot_TestResults__pb2._TESTRESULTS
_PRODUCTCONTENT.fields_by_name['flags'].enum_type = opencannabis_dot_structs_dot_ProductFlags__pb2._PRODUCTFLAG
_PRODUCTCONTENT.fields_by_name['ts'].message_type = _PRODUCTTIMESTAMPS
DESCRIPTOR.message_types_by_name['ProductTimestamps'] = _PRODUCTTIMESTAMPS
DESCRIPTOR.message_types_by_name['ProductContent'] = _PRODUCTCONTENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProductTimestamps = _reflection.GeneratedProtocolMessageType('ProductTimestamps', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTTIMESTAMPS,
  '__module__' : 'opencannabis.content.ProductContent_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.ProductTimestamps)
  })
_sym_db.RegisterMessage(ProductTimestamps)

ProductContent = _reflection.GeneratedProtocolMessageType('ProductContent', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTCONTENT,
  '__module__' : 'opencannabis.content.ProductContent_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.ProductContent)
  })
_sym_db.RegisterMessage(ProductContent)


DESCRIPTOR._options = None
_PRODUCTCONTENT.fields_by_name['media']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Extract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Extract.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\016ExtractProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/products/Extract.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"\x80\x04\n\x07\x45xtract\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.opencannabis.products.Extract.Type\x12\x31\n\x04\x66lag\x18\x03 \x03(\x0e\x32#.opencannabis.products.Extract.Flag\x12\x33\n\x06\x66lower\x18\x04 \x01(\x0b\x32#.opencannabis.base.ProductReference\x12\x35\n\x07product\x18\x05 \x01(\x0b\x32$.opencannabis.content.ProductContent\x12\x35\n\x08material\x18\x06 \x01(\x0b\x32#.opencannabis.content.MaterialsData\"-\n\x04\x46lag\x12\x14\n\x10NO_EXTRACT_FLAGS\x10\x00\x12\x0f\n\x0bSOLVENTLESS\x10\x01\"\x90\x01\n\x04Type\x12\x17\n\x13UNSPECIFIED_EXTRACT\x10\x00\x12\x07\n\x03OIL\x10\x01\x12\x07\n\x03WAX\x10\x02\x12\x0b\n\x07SHATTER\x10\x03\x12\x08\n\x04KIEF\x10\x04\x12\x08\n\x04HASH\x10\x05\x12\x0e\n\nLIVE_RESIN\x10\x06\x12\t\n\x05ROSIN\x10\x07\x12\x0b\n\x07\x43RUMBLE\x10\x08\x12\t\n\x05SAUCE\x10\t\x12\t\n\x05SUGAR\x10\nB:\n\x1eio.opencannabis.schema.productB\x0e\x45xtractProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_EXTRACT_FLAG = _descriptor.EnumDescriptor(
  name='Flag',
  full_name='opencannabis.products.Extract.Flag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_EXTRACT_FLAGS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOLVENTLESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=504,
  serialized_end=549,
)
_sym_db.RegisterEnumDescriptor(_EXTRACT_FLAG)

_EXTRACT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Extract.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_EXTRACT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHATTER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KIEF', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HASH', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIVE_RESIN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROSIN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUMBLE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAUCE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUGAR', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=552,
  serialized_end=696,
)
_sym_db.RegisterEnumDescriptor(_EXTRACT_TYPE)


_EXTRACT = _descriptor.Descriptor(
  name='Extract',
  full_name='opencannabis.products.Extract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Extract.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Extract.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag', full_name='opencannabis.products.Extract.flag', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flower', full_name='opencannabis.products.Extract.flower', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Extract.product', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Extract.material', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXTRACT_FLAG,
    _EXTRACT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=696,
)

_EXTRACT.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_EXTRACT.fields_by_name['type'].enum_type = _EXTRACT_TYPE
_EXTRACT.fields_by_name['flag'].enum_type = _EXTRACT_FLAG
_EXTRACT.fields_by_name['flower'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
_EXTRACT.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_EXTRACT.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_EXTRACT_FLAG.containing_type = _EXTRACT
_EXTRACT_TYPE.containing_type = _EXTRACT
DESCRIPTOR.message_types_by_name['Extract'] = _EXTRACT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Extract = _reflection.GeneratedProtocolMessageType('Extract', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACT,
  '__module__' : 'opencannabis.products.Extract_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Extract)
  })
_sym_db.RegisterMessage(Extract)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/SKU.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.commerce import Item_pb2 as opencannabis_dot_commerce_dot_Item__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/SKU.proto',
  package='opencannabis.products.sku',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.skuH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/products/SKU.proto\x12\x19opencannabis.products.sku\x1a\x19gust/core/datamodel.proto\x1a opencannabis/commerce/Item.proto\"\x9c\x03\n\tMappedSKU\x12\x31\n\x03sku\x18\x01 \x01(\tB$\xc2\xb5\x03\x02\x08\x02\xc2\xb5\x03\x1a\x12\x18SKU value for this item.\x12\x35\n\x07\x66oreign\x18\x02 \x01(\tB$\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x1a\x12\x18SKU value for this item.\x12`\n\x04type\x18\x03 \x01(\x0e\x32\".opencannabis.products.sku.SKUTypeB.\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03$\x12\"Type of SKU this value represents.\x12\x65\n\x06system\x18\x04 \x01(\tBU\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03K\x12IIntegrating system, from which we are referencing a record with this SKU.\x12\x0e\n\x04unit\x18\n \x01(\x08H\x00\x12\x35\n\x07variant\x18\x0b \x01(\x0b\x32\".opencannabis.commerce.VariantSpecH\x00:\x0b\x8a\xf7\x02\x07\x08\x02\x12\x03skuB\x08\n\x06target* \n\x07SKUType\x12\x08\n\x04ITEM\x10\x00\x12\x0b\n\x07PRODUCT\x10\x01\x42&\n\x1aio.opencannabis.schema.skuH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Item__pb2.DESCRIPTOR,])

_SKUTYPE = _descriptor.EnumDescriptor(
  name='SKUType',
  full_name='opencannabis.products.sku.SKUType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ITEM', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=538,
  serialized_end=570,
)
_sym_db.RegisterEnumDescriptor(_SKUTYPE)

SKUType = enum_type_wrapper.EnumTypeWrapper(_SKUTYPE)
ITEM = 0
PRODUCT = 1



_MAPPEDSKU = _descriptor.Descriptor(
  name='MappedSKU',
  full_name='opencannabis.products.sku.MappedSKU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sku', full_name='opencannabis.products.sku.MappedSKU.sku', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\302\265\003\032\022\030SKU value for this item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foreign', full_name='opencannabis.products.sku.MappedSKU.foreign', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003\032\022\030SKU value for this item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.sku.MappedSKU.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003$\022\"Type of SKU this value represents.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system', full_name='opencannabis.products.sku.MappedSKU.system', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003K\022IIntegrating system, from which we are referencing a record with this SKU.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.products.sku.MappedSKU.unit', index=4,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.products.sku.MappedSKU.variant', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\007\010\002\022\003sku',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='opencannabis.products.sku.MappedSKU.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=124,
  serialized_end=536,
)

_MAPPEDSKU.fields_by_name['type'].enum_type = _SKUTYPE
_MAPPEDSKU.fields_by_name['variant'].message_type = opencannabis_dot_commerce_dot_Item__pb2._VARIANTSPEC
_MAPPEDSKU.oneofs_by_name['target'].fields.append(
  _MAPPEDSKU.fields_by_name['unit'])
_MAPPEDSKU.fields_by_name['unit'].containing_oneof = _MAPPEDSKU.oneofs_by_name['target']
_MAPPEDSKU.oneofs_by_name['target'].fields.append(
  _MAPPEDSKU.fields_by_name['variant'])
_MAPPEDSKU.fields_by_name['variant'].containing_oneof = _MAPPEDSKU.oneofs_by_name['target']
DESCRIPTOR.message_types_by_name['MappedSKU'] = _MAPPEDSKU
DESCRIPTOR.enum_types_by_name['SKUType'] = _SKUTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MappedSKU = _reflection.GeneratedProtocolMessageType('MappedSKU', (_message.Message,), {
  'DESCRIPTOR' : _MAPPEDSKU,
  '__module__' : 'opencannabis.products.SKU_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.sku.MappedSKU)
  })
_sym_db.RegisterMessage(MappedSKU)


DESCRIPTOR._options = None
_MAPPEDSKU.fields_by_name['sku']._options = None
_MAPPEDSKU.fields_by_name['foreign']._options = None
_MAPPEDSKU.fields_by_name['type']._options = None
_MAPPEDSKU.fields_by_name['system']._options = None
_MAPPEDSKU._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Timehash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Timehash.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/temporal/Timehash.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"T\n\x08Timehash\x12H\n\tcomponent\x18\x01 \x03(\tB5\xc2\xb5\x03\x31\x12/Entire string, and substrings, of the timehash.B+\n\x1fio.opencannabis.schema.temporalH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_TIMEHASH = _descriptor.Descriptor(
  name='Timehash',
  full_name='opencannabis.temporal.Timehash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='opencannabis.temporal.Timehash.component', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Entire string, and substrings, of the timehash.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=174,
)

DESCRIPTOR.message_types_by_name['Timehash'] = _TIMEHASH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Timehash = _reflection.GeneratedProtocolMessageType('Timehash', (_message.Message,), {
  'DESCRIPTOR' : _TIMEHASH,
  '__module__' : 'opencannabis.temporal.Timehash_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Timehash)
  })
_sym_db.RegisterMessage(Timehash)


DESCRIPTOR._options = None
_TIMEHASH.fields_by_name['component']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Customer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.person import Person_pb2 as opencannabis_dot_person_dot_Person__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Customer.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\rOrderCustomerH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/commerce/Customer.proto\x12\x15opencannabis.commerce\x1a\x19gust/core/datamodel.proto\x1a opencannabis/person/Person.proto\"\xe3\x01\n\x08\x43ustomer\x12Z\n\x06person\x18\x01 \x01(\x0b\x32\x1b.opencannabis.person.PersonB-\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03#\x12!Person attached to this customer.\x12\x41\n\nforeign_id\x18\x02 \x01(\tB-\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03#\x12!Partner-scoped foreign system ID.\x12\x38\n\x08user_key\x18\x03 \x01(\tB&\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x1c\x12\x1aResolved subject user key.B:\n\x1fio.opencannabis.schema.commerceB\rOrderCustomerH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_person_dot_Person__pb2.DESCRIPTOR,])




_CUSTOMER = _descriptor.Descriptor(
  name='Customer',
  full_name='opencannabis.commerce.Customer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='person', full_name='opencannabis.commerce.Customer.person', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003#\022!Person attached to this customer.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foreign_id', full_name='opencannabis.commerce.Customer.foreign_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003#\022!Partner-scoped foreign system ID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_key', full_name='opencannabis.commerce.Customer.user_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003\034\022\032Resolved subject user key.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=352,
)

_CUSTOMER.fields_by_name['person'].message_type = opencannabis_dot_person_dot_Person__pb2._PERSON
DESCRIPTOR.message_types_by_name['Customer'] = _CUSTOMER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Customer = _reflection.GeneratedProtocolMessageType('Customer', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMER,
  '__module__' : 'opencannabis.commerce.Customer_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.Customer)
  })
_sym_db.RegisterMessage(Customer)


DESCRIPTOR._options = None
_CUSTOMER.fields_by_name['person']._options = None
_CUSTOMER.fields_by_name['foreign_id']._options = None
_CUSTOMER.fields_by_name['user_key']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/contact/PhoneNumber.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/contact/PhoneNumber.proto',
  package='opencannabis.contact',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contactB\014ContactPhoneH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&opencannabis/contact/PhoneNumber.proto\x12\x14opencannabis.contact\x1a\x19gust/core/datamodel.proto\"\xea\x02\n\x0bPhoneNumber\x12\x34\n\x04\x65\x31\x36\x34\x18\x01 \x01(\tB&\xc2\xb5\x03\"\x12 E164-formatted telephone number.\x12\x41\n\tvalidated\x18\x02 \x01(\x08\x42.\xc2\xb5\x03*\x12(Validation status for this phone number.\x12I\n\x07\x64isplay\x18\x03 \x01(\tB8\xc2\xb5\x03\x34\x12\x32\x44isplay text for this phone number, if applicable.\x12I\n\x0ctext_capable\x18\x04 \x01(\x08\x42\x33\xc2\xb5\x03/\x12-Whether this number can send and receive SMS.\x12L\n\rvoice_capable\x18\x05 \x01(\x08\x42\x35\xc2\xb5\x03\x31\x12/Whether this number can send and receive calls.B8\n\x1eio.opencannabis.schema.contactB\x0c\x43ontactPhoneH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_PHONENUMBER = _descriptor.Descriptor(
  name='PhoneNumber',
  full_name='opencannabis.contact.PhoneNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='e164', full_name='opencannabis.contact.PhoneNumber.e164', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 E164-formatted telephone number.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validated', full_name='opencannabis.contact.PhoneNumber.validated', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003*\022(Validation status for this phone number.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display', full_name='opencannabis.contact.PhoneNumber.display', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034\0222Display text for this phone number, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_capable', full_name='opencannabis.contact.PhoneNumber.text_capable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003/\022-Whether this number can send and receive SMS.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_capable', full_name='opencannabis.contact.PhoneNumber.voice_capable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Whether this number can send and receive calls.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=454,
)

DESCRIPTOR.message_types_by_name['PhoneNumber'] = _PHONENUMBER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PhoneNumber = _reflection.GeneratedProtocolMessageType('PhoneNumber', (_message.Message,), {
  'DESCRIPTOR' : _PHONENUMBER,
  '__module__' : 'opencannabis.contact.PhoneNumber_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.contact.PhoneNumber)
  })
_sym_db.RegisterMessage(PhoneNumber)


DESCRIPTOR._options = None
_PHONENUMBER.fields_by_name['e164']._options = None
_PHONENUMBER.fields_by_name['validated']._options = None
_PHONENUMBER.fields_by_name['display']._options = None
_PHONENUMBER.fields_by_name['text_capable']._options = None
_PHONENUMBER.fields_by_name['voice_capable']._options = None
# @@protoc_insertion_point(module_scope)



# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.structs.pricing`
  -------------------------------------
  Structures that define pricing data and sale/discount info.

"""

# `opencannabis.structs.pricing`



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/USState.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/USState.proto',
  package='opencannabis.geo.usa',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.geo.usaH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eopencannabis/geo/USState.proto\x12\x14opencannabis.geo.usa*\xa1\t\n\x07USState\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02\x41L\x10\x01\x12\x0b\n\x07\x41LABAMA\x10\x01\x12\x06\n\x02\x41K\x10\x02\x12\n\n\x06\x41LASKA\x10\x02\x12\x06\n\x02\x41Z\x10\x03\x12\x0b\n\x07\x41RIZONA\x10\x03\x12\x06\n\x02\x41R\x10\x04\x12\x0c\n\x08\x41RKANSAS\x10\x04\x12\x06\n\x02\x43\x41\x10\x05\x12\x0e\n\nCALIFORNIA\x10\x05\x12\x06\n\x02\x43O\x10\x06\x12\x0c\n\x08\x43OLORADO\x10\x06\x12\x06\n\x02\x43T\x10\x07\x12\x0f\n\x0b\x43ONNECTICUT\x10\x07\x12\x06\n\x02\x44\x45\x10\x08\x12\x0c\n\x08\x44\x65laware\x10\x08\x12\x06\n\x02\x44\x43\x10\t\x12\x18\n\x14\x44ISTRICT_OF_COLUMBIA\x10\t\x12\x06\n\x02\x46L\x10\n\x12\x0b\n\x07\x46LORIDA\x10\n\x12\x06\n\x02GA\x10\x0b\x12\x0b\n\x07GEORGIA\x10\x0b\x12\x06\n\x02HI\x10\x0c\x12\n\n\x06HAWAII\x10\x0c\x12\x06\n\x02ID\x10\r\x12\t\n\x05IDAHO\x10\r\x12\x06\n\x02IL\x10\x0e\x12\x0c\n\x08ILLINOIS\x10\x0e\x12\x06\n\x02IN\x10\x0f\x12\x0b\n\x07INDIANA\x10\x0f\x12\x06\n\x02IA\x10\x10\x12\x08\n\x04IOWA\x10\x10\x12\x06\n\x02KS\x10\x11\x12\n\n\x06KANSAS\x10\x11\x12\x06\n\x02KY\x10\x12\x12\x0c\n\x08KENTUCKY\x10\x12\x12\x06\n\x02LA\x10\x13\x12\x0c\n\x08LOISIANA\x10\x13\x12\x06\n\x02ME\x10\x14\x12\t\n\x05MAINE\x10\x14\x12\x06\n\x02MD\x10\x15\x12\x0c\n\x08MARYLAND\x10\x15\x12\x06\n\x02MA\x10\x16\x12\x11\n\rMASSACHUSETTS\x10\x16\x12\x06\n\x02MI\x10\x17\x12\x0c\n\x08MICHIGAN\x10\x17\x12\x06\n\x02MN\x10\x18\x12\r\n\tMINNESOTA\x10\x18\x12\x06\n\x02MS\x10\x19\x12\x0f\n\x0bMISSISSIPPI\x10\x19\x12\x06\n\x02MO\x10\x1a\x12\x0c\n\x08MISSOURI\x10\x1a\x12\x06\n\x02MT\x10\x1b\x12\x0b\n\x07MONTANA\x10\x1b\x12\x06\n\x02NE\x10\x1c\x12\x0c\n\x08NEBRASKA\x10\x1c\x12\x06\n\x02NV\x10\x1d\x12\n\n\x06NEVADA\x10\x1d\x12\x06\n\x02NH\x10\x1e\x12\x11\n\rNEW_HAMPSHIRE\x10\x1e\x12\x06\n\x02NJ\x10\x1f\x12\x0e\n\nNEW_JERSEY\x10\x1f\x12\x06\n\x02NM\x10 \x12\x0e\n\nNEW_MEXICO\x10 \x12\x06\n\x02NY\x10!\x12\x0c\n\x08NEW_YORK\x10!\x12\x06\n\x02NC\x10\"\x12\x12\n\x0eNORTH_CAROLINA\x10\"\x12\x06\n\x02ND\x10#\x12\x10\n\x0cNORTH_DAKOTA\x10#\x12\x06\n\x02OH\x10$\x12\x08\n\x04OHIO\x10$\x12\x06\n\x02OK\x10%\x12\x0c\n\x08OKLAHOMA\x10%\x12\x06\n\x02OR\x10&\x12\n\n\x06OREGON\x10&\x12\x06\n\x02PA\x10\'\x12\x10\n\x0cPENNSYLVANIA\x10\'\x12\x06\n\x02RI\x10(\x12\x10\n\x0cRHODE_ISLAND\x10(\x12\x06\n\x02SC\x10)\x12\x12\n\x0eSOUTH_CAROLINA\x10)\x12\x06\n\x02SD\x10*\x12\x10\n\x0cSOUTH_DAKOTA\x10*\x12\x06\n\x02TN\x10+\x12\r\n\tTENNESSEE\x10+\x12\x06\n\x02TX\x10,\x12\t\n\x05TEXAS\x10,\x12\x06\n\x02UT\x10-\x12\x08\n\x04UTAH\x10-\x12\x06\n\x02VT\x10.\x12\x0b\n\x07VERMONT\x10.\x12\x06\n\x02VA\x10/\x12\x0c\n\x08VIRGINIA\x10/\x12\x06\n\x02WA\x10\x30\x12\x0e\n\nWASHINGTON\x10\x30\x12\x06\n\x02WV\x10\x31\x12\x11\n\rWEST_VIRGINIA\x10\x31\x12\x06\n\x02WI\x10\x32\x12\r\n\tWISCONSIN\x10\x32\x12\x0b\n\x07WYOMING\x10\x33\x12\x06\n\x02WY\x10\x33\x1a\x02\x10\x01\x42*\n\x1eio.opencannabis.schema.geo.usaH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_USSTATE = _descriptor.EnumDescriptor(
  name='USState',
  full_name='opencannabis.geo.usa.USState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALABAMA', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AK', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALASKA', index=4, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AZ', index=5, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARIZONA', index=6, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AR', index=7, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ARKANSAS', index=8, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CA', index=9, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CALIFORNIA', index=10, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CO', index=11, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLORADO', index=12, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CT', index=13, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONNECTICUT', index=14, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DE', index=15, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Delaware', index=16, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DC', index=17, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISTRICT_OF_COLUMBIA', index=18, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FL', index=19, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLORIDA', index=20, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GA', index=21, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEORGIA', index=22, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HI', index=23, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HAWAII', index=24, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ID', index=25, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IDAHO', index=26, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IL', index=27, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ILLINOIS', index=28, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN', index=29, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDIANA', index=30, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IA', index=31, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IOWA', index=32, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KS', index=33, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KANSAS', index=34, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KY', index=35, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KENTUCKY', index=36, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LA', index=37, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOISIANA', index=38, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ME', index=39, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAINE', index=40, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MD', index=41, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARYLAND', index=42, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MA', index=43, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MASSACHUSETTS', index=44, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MI', index=45, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MICHIGAN', index=46, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MN', index=47, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINNESOTA', index=48, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MS', index=49, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSISSIPPI', index=50, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MO', index=51, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MISSOURI', index=52, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MT', index=53, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTANA', index=54, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NE', index=55, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEBRASKA', index=56, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NV', index=57, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEVADA', index=58, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NH', index=59, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEW_HAMPSHIRE', index=60, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NJ', index=61, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEW_JERSEY', index=62, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NM', index=63, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEW_MEXICO', index=64, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NY', index=65, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEW_YORK', index=66, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NC', index=67, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORTH_CAROLINA', index=68, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ND', index=69, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORTH_DAKOTA', index=70, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OH', index=71, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OHIO', index=72, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OK', index=73, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OKLAHOMA', index=74, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OR', index=75, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OREGON', index=76, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PA', index=77, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENNSYLVANIA', index=78, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RI', index=79, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RHODE_ISLAND', index=80, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SC', index=81, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUTH_CAROLINA', index=82, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SD', index=83, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOUTH_DAKOTA', index=84, number=42,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TN', index=85, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TENNESSEE', index=86, number=43,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TX', index=87, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXAS', index=88, number=44,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UT', index=89, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UTAH', index=90, number=45,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VT', index=91, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERMONT', index=92, number=46,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VA', index=93, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRGINIA', index=94, number=47,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WA', index=95, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WASHINGTON', index=96, number=48,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WV', index=97, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEST_VIRGINIA', index=98, number=49,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WI', index=99, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WISCONSIN', index=100, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WYOMING', index=101, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WY', index=102, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\020\001',
  serialized_start=57,
  serialized_end=1242,
)
_sym_db.RegisterEnumDescriptor(_USSTATE)

USState = enum_type_wrapper.EnumTypeWrapper(_USSTATE)
UNSPECIFIED = 0
AL = 1
ALABAMA = 1
AK = 2
ALASKA = 2
AZ = 3
ARIZONA = 3
AR = 4
ARKANSAS = 4
CA = 5
CALIFORNIA = 5
CO = 6
COLORADO = 6
CT = 7
CONNECTICUT = 7
DE = 8
Delaware = 8
DC = 9
DISTRICT_OF_COLUMBIA = 9
FL = 10
FLORIDA = 10
GA = 11
GEORGIA = 11
HI = 12
HAWAII = 12
ID = 13
IDAHO = 13
IL = 14
ILLINOIS = 14
IN = 15
INDIANA = 15
IA = 16
IOWA = 16
KS = 17
KANSAS = 17
KY = 18
KENTUCKY = 18
LA = 19
LOISIANA = 19
ME = 20
MAINE = 20
MD = 21
MARYLAND = 21
MA = 22
MASSACHUSETTS = 22
MI = 23
MICHIGAN = 23
MN = 24
MINNESOTA = 24
MS = 25
MISSISSIPPI = 25
MO = 26
MISSOURI = 26
MT = 27
MONTANA = 27
NE = 28
NEBRASKA = 28
NV = 29
NEVADA = 29
NH = 30
NEW_HAMPSHIRE = 30
NJ = 31
NEW_JERSEY = 31
NM = 32
NEW_MEXICO = 32
NY = 33
NEW_YORK = 33
NC = 34
NORTH_CAROLINA = 34
ND = 35
NORTH_DAKOTA = 35
OH = 36
OHIO = 36
OK = 37
OKLAHOMA = 37
OR = 38
OREGON = 38
PA = 39
PENNSYLVANIA = 39
RI = 40
RHODE_ISLAND = 40
SC = 41
SOUTH_CAROLINA = 41
SD = 42
SOUTH_DAKOTA = 42
TN = 43
TENNESSEE = 43
TX = 44
TEXAS = 44
UT = 45
UTAH = 45
VT = 46
VERMONT = 46
VA = 47
VIRGINIA = 47
WA = 48
WASHINGTON = 48
WV = 49
WEST_VIRGINIA = 49
WI = 50
WISCONSIN = 50
WYOMING = 51
WY = 51


DESCRIPTOR.enum_types_by_name['USState'] = _USSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
_USSTATE._options = None
# @@protoc_insertion_point(module_scope)
